summaryrefslogtreecommitdiffstats
path: root/StdLib
diff options
context:
space:
mode:
Diffstat (limited to 'StdLib')
-rw-r--r--StdLib/LibC/String/Copying.c5
-rw-r--r--StdLib/LibC/gdtoa/gdtoa.inf1
2 files changed, 4 insertions, 2 deletions
diff --git a/StdLib/LibC/gdtoa/gdtoa.inf b/StdLib/LibC/gdtoa/gdtoa.inf
index fbe3ac1b63..48b7df403f 100644
--- a/StdLib/LibC/gdtoa/gdtoa.inf
+++ b/StdLib/LibC/gdtoa/gdtoa.inf
@@ -44,6 +44,7 @@
[Sources.ARM]
strtof.c
+ Ipf/strtold.c
[Sources]
strtod.c # Public interfaces
diff --git a/StdLib/LibC/String/Copying.c b/StdLib/LibC/String/Copying.c
index 18498d6f87..e27519e24c 100644
--- a/StdLib/LibC/String/Copying.c
+++ b/StdLib/LibC/String/Copying.c
@@ -19,11 +19,12 @@
#include <stdlib.h>
#include <string.h>
/** Do not define memcpy for IPF+GCC builds.
For IPF, using a GCC compiler, the memcpy function is converted to
CopyMem by objcpy during build.
+ For ARM, the memcpy function is provided by the CompilerIntrinsics library.
**/
-#if !(defined(MDE_CPU_IPF) && defined(__GNUC__))
+#if !((defined(MDE_CPU_IPF) || defined(MDE_CPU_ARM)) && defined(__GNUC__))
/** The memcpy function copies n characters from the object pointed to by s2
into the object pointed to by s1.
@@ -19,11 +19,12 @@
#include <stdlib.h>
#include <string.h>
-/** Do not define memcpy for IPF+GCC builds.
+/** Do not define memcpy for IPF+GCC or ARM+GCC builds.
For IPF, using a GCC compiler, the memcpy function is converted to
CopyMem by objcpy during build.